<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace local_rwth_sd_sync\event;

class course_event_synchronization_failed extends \core\event\base {

    /**
     * Init method.
     *
     * @return void
     */
    protected function init() {
        $this->data['crud'] = 'c';
        $this->data['edulevel'] = self::LEVEL_OTHER;
    }

    /**
     * Return localised event name.
     *
     * @return string
     */
    public static function get_name() {
        return get_string('course_event_synchronization_failed', 'local_rwth_sd_sync');
    }

    /**
     * Returns description of what happened.
     *
     * @return string
     */
    public function get_description() {
        $desc = "The synchronization of an event for the course with {$this->other['courselocalfield']} '{$this->other['courselocalfieldvalue']}' failed.";
        if (array_key_exists('error', $this->other)) {
            $desc .= " ({$this->other['error']})";
        }
        return $desc;
    }

    /**
     * Returns relevant URL.
     *
     * @return \moodle_url
     */
    public function get_url() {
        return null;
    }

    /**
     * Custom validation.
     *
     * @throws \coding_exception
     * @return void
     */
    protected function validate_data() {
        parent::validate_data();

        if (!array_key_exists('courselocalfield', $this->other)) {
            throw new \coding_exception('The \'courselocalfield\' must be set.');
        }

        if (!array_key_exists('courselocalfieldvalue', $this->other)) {
            throw new \coding_exception('The \'courselocalfieldvalue\' must be set.');
        }
    }
}

