<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Database enrolment plugin settings and presets.
 *
 * @package    local_rwth_sd_sync based on enrol_database
 * @copyright  2010 Petr Skoda {@link http://skodak.org}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

// Ensure the configurations for this site are set
if ($hassiteconfig) {

    $settings = new admin_settingpage( 'local_rwth_sd_sync', get_string('generalsettings', 'local_rwth_sd_sync'));
    $ADMIN->add('localplugins', $settings);

    //--- general settings -----------------------------------------------------------------------------------
    $settings->add(new admin_setting_heading('local_rwth_sd_sync_settings', '', get_string('pluginname_desc', 'local_rwth_sd_sync')));

    $settings->add(new admin_setting_heading('local_rwth_sd_sync_exdbheader', get_string('settingsheaderdb', 'local_rwth_sd_sync'), ''));

    $options = array('', "access", "ado_access", "ado", "ado_mssql", "borland_ibase", "csv", "db2", "fbsql", "firebird", "ibase", "informix72", "informix", "mssql", "mssql_n", "mssqlnative", "mysql", "mysqli", "mysqlt", "oci805", "oci8", "oci8po", "odbc", "odbc_mssql", "odbc_oracle", "oracle", "pdo", "postgres64", "postgres7", "postgres", "proxy", "sqlanywhere", "sybase", "vfp");
    $options = array_combine($options, $options);
    $settings->add(new admin_setting_configselect('local_rwth_sd_sync/dbtype', get_string('dbtype', 'local_rwth_sd_sync'), get_string('dbtype_desc', 'local_rwth_sd_sync'), '', $options));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/dbhost', get_string('dbhost', 'local_rwth_sd_sync'), get_string('dbhost_desc', 'local_rwth_sd_sync'), 'localhost'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/dbuser', get_string('dbuser', 'local_rwth_sd_sync'), '', ''));
    $settings->add(new admin_setting_configpasswordunmask('local_rwth_sd_sync/dbpass', get_string('dbpass', 'local_rwth_sd_sync'), '', ''));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/dbname', get_string('dbname', 'local_rwth_sd_sync'), get_string('dbname_desc', 'local_rwth_sd_sync'), ''));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/dbencoding', get_string('dbencoding', 'local_rwth_sd_sync'), '', 'utf-8'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/dbsetupsql', get_string('dbsetupsql', 'local_rwth_sd_sync'), get_string('dbsetupsql_desc', 'local_rwth_sd_sync'), ''));
    $settings->add(new admin_setting_configcheckbox('local_rwth_sd_sync/dbsybasequoting', get_string('dbsybasequoting', 'local_rwth_sd_sync'), get_string('dbsybasequoting_desc', 'local_rwth_sd_sync'), 0));
    $settings->add(new admin_setting_configcheckbox('local_rwth_sd_sync/debugdb', get_string('debugdb', 'local_rwth_sd_sync'), get_string('debugdb_desc', 'local_rwth_sd_sync'), 0));


    $settings->add(new admin_setting_heading('local_rwth_sd_sync_localheader', get_string('settingsheaderlocal', 'local_rwth_sd_sync'), ''));

    $options = array('idnumber'=>'idnumber', 'shortname'=>'shortname');
    $settings->add(new admin_setting_configselect('local_rwth_sd_sync/localcoursefield', get_string('localcoursefield', 'local_rwth_sd_sync'), '', 'idnumber', $options));

    $options = array('id'=>'id', 'idnumber'=>'idnumber');
    $settings->add(new admin_setting_configselect('local_rwth_sd_sync/localcategoryfield', get_string('localcategoryfield', 'local_rwth_sd_sync'), '', 'id', $options));


    $settings->add(new admin_setting_heading('local_rwth_sd_sync_newcoursesheader', get_string('settingsheadernewcourses', 'local_rwth_sd_sync'), ''));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcoursetable', get_string('newcoursetable', 'local_rwth_sd_sync'), get_string('newcoursetable_desc', 'local_rwth_sd_sync'), 'Veranstaltung'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcoursefullname', get_string('newcoursefullname', 'local_rwth_sd_sync'), '', 'Title'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcourseshortname', get_string('newcourseshortname', 'local_rwth_sd_sync'), '', 'Shortname'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcourseidnumber', get_string('newcourseidnumber', 'local_rwth_sd_sync'), '', 'ID'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcoursedescription', get_string('newcoursedescription', 'local_rwth_sd_sync'), '', 'Description'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcoursestartdate', get_string('newcoursestartdate', 'local_rwth_sd_sync'), '', 'Start'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcourseenddate', get_string('newcourseenddate', 'local_rwth_sd_sync'), '', 'End'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcoursecategory', get_string('newcoursecategory', 'local_rwth_sd_sync'), '', ''));
    $settings->add(new admin_setting_configtextarea('local_rwth_sd_sync/newcoursecustomfields', get_string('newcoursecustomfields', 'local_rwth_sd_sync'), get_string('newcoursecustomfields_desc', 'local_rwth_sd_sync'), ''));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/newcoursemoodleinternalid', get_string('newcoursemoodleinternalid', 'local_rwth_sd_sync'), get_string('newcoursemoodleinternalid_desc', 'local_rwth_sd_sync'), 'MoodleInterneId'));

    require_once($CFG->dirroot.'/local/rwth_sd_sync/settingslib.php');
    $settings->add(new local_rwth_sd_sync_admin_setting_category('local_rwth_sd_sync/defaultcategory', get_string('defaultcategory', 'local_rwth_sd_sync'), get_string('defaultcategory_desc', 'local_rwth_sd_sync')));

    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/templatecourse', get_string('templatecourse', 'local_rwth_sd_sync'), get_string('templatecourse_desc', 'local_rwth_sd_sync'), ''));

    $settings->add(new admin_setting_configcheckbox('local_rwth_sd_sync/courseidwriteback', get_string('courseidwriteback', 'local_rwth_sd_sync'), get_string('courseidwriteback_desc', 'local_rwth_sd_sync'), 1));


    $settings->add(new admin_setting_heading('local_rwth_sd_sync_groupheader', get_string('settingsheadergroup', 'local_rwth_sd_sync'), ''));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/grouptable', get_string('grouptable', 'local_rwth_sd_sync'), '', 'LvGruppen'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupcoursefield', get_string('group-course-field', 'local_rwth_sd_sync'), '', 'Veranstaltung'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupidfield', get_string('group-id-field', 'local_rwth_sd_sync'), '', 'GRP_ID'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupnamefield', get_string('group-name-field', 'local_rwth_sd_sync'), '', 'GRP_Name'));

    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupparticipantstable', get_string('group-participants-table', 'local_rwth_sd_sync'), '', 'TeilnehmerInGrp'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupparticipantsgroupidfield', get_string('group-participants-groupid-field', 'local_rwth_sd_sync'), '', 'GRP_ID'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupparticipantsusernamefield', get_string('group-participants-username-field', 'local_rwth_sd_sync'), '', 'MoodleUsername'));

    $settings->add(new admin_setting_heading('local_rwth_sd_sync_appointmentheader', get_string('settingsheaderappointment', 'local_rwth_sd_sync'), ''));

    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmenttable', get_string('courseappointmenttable', 'local_rwth_sd_sync'), '', 'TermineKurs'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentcoursefield', get_string('courseappointmentcoursefield', 'local_rwth_sd_sync'), '', 'Veranstaltung'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentroomfield', get_string('courseappointmentroomfield', 'local_rwth_sd_sync'), '', 'Room'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentlocationfield', get_string('courseappointmentlocationfield', 'local_rwth_sd_sync'), '', 'Location'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentstartfield', get_string('courseappointmentstartfield', 'local_rwth_sd_sync'), '', 'Start'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentendfield', get_string('courseappointmentendfield', 'local_rwth_sd_sync'), '', 'End'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentkeywordfield', get_string('courseappointmentkeywordfield', 'local_rwth_sd_sync'), '', 'Keyword'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentronidfield', get_string('courseappointmentronidfield', 'local_rwth_sd_sync'), '', 'Notes'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/courseappointmentsubjectfield', get_string('courseappointmentsubjectfield', 'local_rwth_sd_sync'), '', 'Subject'));

    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmenttable', get_string('groupappointmenttable', 'local_rwth_sd_sync'), '', 'TermineGruppe'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentgroupidfield', get_string('groupappointmentgroupidfield', 'local_rwth_sd_sync'), '', 'GRP_ID'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentroomfield', get_string('groupappointmentroomfield', 'local_rwth_sd_sync'), '', 'Room'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentlocationfield', get_string('groupappointmentlocationfield', 'local_rwth_sd_sync'), '', 'Location'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentstartfield', get_string('groupappointmentstartfield', 'local_rwth_sd_sync'), '', 'Start'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentendfield', get_string('groupappointmentendfield', 'local_rwth_sd_sync'), '', 'End'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentkeywordfield', get_string('groupappointmentkeywordfield', 'local_rwth_sd_sync'), '', 'Keyword'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentronidfield', get_string('groupappointmentronidfield', 'local_rwth_sd_sync'), '', 'Notes'));
    $settings->add(new admin_setting_configtext('local_rwth_sd_sync/groupappointmentsubjectfield', get_string('groupappointmentsubjectfield', 'local_rwth_sd_sync'), '', 'Subject'));

    $settings->add(new admin_setting_heading('local_rwth_sd_sync_loggingheader', get_string('settingsheaderlogging', 'local_rwth_sd_sync'), ''));

    $settings->add(new admin_setting_configcheckbox('local_rwth_sd_sync/verboselogging', get_string('verboselogging', 'local_rwth_sd_sync'), get_string('verboselogging_desc', 'local_rwth_sd_sync'), 0));
    $settings->add(new admin_setting_configcheckbox('local_rwth_sd_sync/debugging', get_string('debugging', 'local_rwth_sd_sync'), get_string('debugging_desc', 'local_rwth_sd_sync'), 0));

}
